MutexType

Enum MutexType 

pub enum MutexType {
    Normal,
    ErrorCheck,
    Recursive,
}
The type of the mutex. See pthread_mutex_lock for more information.

Variants



Normal

If a thread already holds a lock and attempts to lock the mutex again, the POSIX standard mandates that a deadlock occur. However, some platforms will return a MutexLockError::Deadlock despite the mutex not being error-checked.



ErrorCheck

If a thread already holds a lock and attempts to lock the mutex again, MutexLockError::Deadlock is returned.



Recursive

If a thread already holds a lock and attempts to lock the mutex again, the call will succeed as long as the recursive lock limit is not exceeded.