pub struct RawRwLockAlloc { /* private fields */ }Expand description
Cast to a pointer of this type when constructing a rwlock from a raw pointer.
This is a pthread_rwlock_t that has been made !Unpin, because a rwlock must not be
relocated once it has been initialised. The two associated constants describe how much room to
leave for one when carving up a shared mapping by hand.
Implementations